import 'option.dart';
import 'terminal.dart';

// to declare a class instance variable as const, the class constructor
// must be marked as const as well ( const Terminal() ).
// if we declare multiple instances of the const class,
// they all will have the same value in memory
// const t1=Teminal();
// const t2=Teminal();
// print(t1 == t2) ==> true

// and this variable is also marked as private
// to be used only inside this file
const _terminal = Terminal();

class Prompter {
  String _ask(String prompt, List<Option> options) {
    _terminal.clearScreen();
    _terminal.printPrompt(prompt);
    _terminal.printOptions(options);
    return _terminal.collectInput();
  }

  dynamic askMultipleChoiceQuestion(String prompt, List<Option> options) {
    final input = _ask(prompt, options);

    try {
      return options[int.parse(input) - 1].value;
    } catch (e) {
      return askMultipleChoiceQuestion(prompt, options);
    }
  }

  bool askYesNoQuestion(String prompt) {
    final input = _ask('$prompt (y/n)', []).toLowerCase();
    try {
      if (input == 'y' || input == 'yes') {
        return true;
      } else if (input == 'n' || input == 'no') {
        return false;
      } else {
        throw Error();
      }
    } catch (e) {
      return askYesNoQuestion(prompt);
    }
  }
}
